@@ -34,13 +34,14 @@ class Fpm:
   def run(self, name, version, deps, devel_deps, extra_deps, RPMS_GENERATED = []):
     """ Prepares arguments and executes fpm """
     fullVersion = version
+    version = version.replace('local', '', 1)
     # split version and revision
     version_split = version.split('-')
     # split in case of vX.Y.Z-R
     # don't split if e.g. latest-o2-dataflow
     if len(version_split) == 2:
         version = version_split[0]
-        iterationArg = ['--iteration', version_split[1] + '.' + self.release_suffix]
+        iterationArg = ['--iteration', version_split[1].replace('local', '', 1) + '.' + self.release_suffix]
     else:
         iterationArg = ['--iteration', self.release_suffix]
 
@@ -67,7 +68,7 @@ class Fpm:
                  % (name, version, list(deps.items()), extra_deps, list({**devel_deps, **self.convertDepsToDevel(deps)}.items())))
 
     # Handle extra_deps
-    extra_deps = [v for dep in extra_deps for v in ('--depends', dep)]
+    extra_deps = [v for dep in extra_deps for v in ('--depends', dep.replace('local', '', 1))]
 
     packageName = self.packagePrefix + name
     fpmCommand = ['fpm',
@@ -159,7 +160,7 @@ class Fpm:
             countDashes = depVersion.count('-')
             if countDashes > 1:
                 depVersion = depVersion.replace('-', '_', countDashes - 1)
-            depsArg.extend(['--depends', self.packagePrefix + depName + ' >= ' + depVersion])
+            depsArg.extend(['--depends', self.packagePrefix + depName + ' >= ' + depVersion.replace('local', '', 1)])
         else:  # coming from system, get name from dict
           if depName not in self.runtimeDepsDict:
             logging.critical('Could not find system dependency: %s \nDoes it suppose to come from aliBuild?' % (depName))
